@@ -15,7 +15,6 @@
 #include "ft2_tables.h"
 #include "ft2_structs.h"
 #include "mixer/ft2_mix.h"
-#include "mixer/ft2_center_mix.h"
 #include "mixer/ft2_silence_mix.h"
 
 // hide POSIX warnings
@@ -26,7 +25,7 @@
 static int32_t smpShiftValue;
 static uint32_t oldAudioFreq, tickTimeLenInt;
 static uint64_t tickTimeLenFrac;
-static double dAudioNormalizeMul, dSqrtPanningTable[256+1];
+static float fAudioNormalizeMul, fSqrtPanningTable[256+1];
 static voice_t voice[MAX_CHANNELS * 2];
 
 // globalized
@@ -115,7 +114,7 @@ void setAudioAmp(int16_t amp, int16_t masterVol, bool bitDepth32Flag)
 	if (!bitDepth32Flag)
 		dAmp *= 32768.0;
 
-	dAudioNormalizeMul = dAmp;
+	fAudioNormalizeMul = (float)dAmp;
 }
 
 void decreaseMasterVol(void)
@@ -196,18 +195,24 @@ void audioSetInterpolationType(uint8_t interpolationType)
 	lockMixerCallback();
 	audio.interpolationType = interpolationType;
 
-	// set sinc polyphase LUT pointers
+	audio.sincInterpolation = false;
+
+	// set sinc LUT pointers
 	if (config.interpolation == INTERPOLATION_SINC8)
 	{
 		fKaiserSinc = fKaiserSinc_8;
 		fDownSample1 = fDownSample1_8;
 		fDownSample2 = fDownSample2_8;
+
+		audio.sincInterpolation = true;
 	}
 	else if (config.interpolation == INTERPOLATION_SINC16)
 	{
 		fKaiserSinc = fKaiserSinc_16;
 		fDownSample1 = fDownSample1_16;
 		fDownSample2 = fDownSample2_16;
+
+		audio.sincInterpolation = true;
 	}
 
 	unlockMixerCallback();
@@ -217,15 +222,15 @@ void calcPanningTable(void)
 {
 	// same formula as FT2's panning table (with 0.0 .. 1.0 scale)
 	for (int32_t i = 0; i <= 256; i++)
-		dSqrtPanningTable[i] = sqrt(i / 256.0);
+		fSqrtPanningTable[i] = (float)sqrt(i / 256.0);
 }
 
 static void voiceUpdateVolumes(int32_t i, uint8_t status)
 {
 	voice_t *v = &voice[i];
 
-	v->fTargetVolumeL = (float)(v->dVolume * dSqrtPanningTable[256-v->panning]);
-	v->fTargetVolumeR = (float)(v->dVolume * dSqrtPanningTable[    v->panning]);
+	v->fTargetVolumeL = v->fVolume * fSqrtPanningTable[256-v->panning];
+	v->fTargetVolumeR = v->fVolume * fSqrtPanningTable[    v->panning];
 
 	if (!audio.volumeRampingFlag)
 	{
@@ -250,7 +255,7 @@ static void voiceUpdateVolumes(int32_t i, uint8_t status)
 
 			voice_t *f = &voice[MAX_CHANNELS+i];
 
-			*f = *v; // store current voice in respective fadeout ramp voice
+			*f = *v; // copy current voice to new fadeout-ramp voice
 
 			const float fVolumeLDiff = 0.0f - f->fCurrVolumeL;
 			const float fVolumeRDiff = 0.0f - f->fCurrVolumeR;
@@ -310,13 +315,13 @@ static void voiceTrigger(int32_t ch, sample_t *s, int32_t position)
 	{
 		v->base16 = (const int16_t *)s->dataPtr;
 		v->revBase16 = &v->base16[loopStart + loopEnd]; // for pingpong loops
-		v->leftEdgeTaps16 = s->leftEdgeTapSamples16 + SINC_MAX_LEFT_TAPS;
+		v->leftEdgeTaps16 = s->leftEdgeTapSamples16 + MAX_LEFT_TAPS;
 	}
 	else
 	{
 		v->base8 = s->dataPtr;
 		v->revBase8 = &v->base8[loopStart + loopEnd]; // for pingpong loops
-		v->leftEdgeTaps8 = s->leftEdgeTapSamples8 + SINC_MAX_LEFT_TAPS;
+		v->leftEdgeTaps8 = s->leftEdgeTapSamples8 + MAX_LEFT_TAPS;
 	}
 
 	v->hasLooped = false; // for sinc interpolation special case
@@ -335,7 +340,7 @@ static void voiceTrigger(int32_t ch, sample_t *s, int32_t position)
 		return;
 	}
 
-	v->mixFuncOffset = ((int32_t)sample16Bit * 12) + (audio.interpolationType * 3) + loopType;
+	v->mixFuncOffset = ((int32_t)sample16Bit * 15) + (audio.interpolationType * 3) + loopType;
 	v->active = true;
 }
 
@@ -365,10 +370,10 @@ void updateVoices(void)
 
 		if (status & IS_Vol)
 		{
-			v->dVolume = ch->dFinalVol;
+			v->fVolume = ch->fFinalVol;
 
 			// set scope volume
-			const int32_t scopeVolume = (int32_t)((SCOPE_HEIGHT * ch->dFinalVol) + 0.5); // rounded
+			const int32_t scopeVolume = (int32_t)((SCOPE_HEIGHT * ch->fFinalVol) + 0.5f); // rounded
 			v->scopeVolume = (uint8_t)scopeVolume;
 		}
 
@@ -385,29 +390,24 @@ void updateVoices(void)
 			{
 				ch->oldFinalPeriod = ch->finalPeriod;
 
-				if (ch->finalPeriod == 0) // in FT2, period 0 -> delta 0
-				{
-					v->scopeDelta = 0;
-					v->oldDelta = 0;
-					v->fSincLUT = fKaiserSinc;
-				}
-				else
-				{
-					const double dHz = dPeriod2Hz(ch->finalPeriod);
-					const uintCPUWord_t delta = v->oldDelta = (intCPUWord_t)((dHz * audio.dHz2MixDeltaMul) + 0.5); // Hz -> fixed-point delta (rounded)
+				const double dHz = dPeriod2Hz(ch->finalPeriod);
 
-					// decide which polyphase sinc LUT to use according to resampling ratio
-					if (delta <= (uintCPUWord_t)(1.1875 * MIXER_FRAC_SCALE))
+				// set voice delta
+				const uint64_t delta = v->oldDelta = (int64_t)((dHz * audio.dHz2MixDeltaMul) + 0.5); // Hz -> fixed-point delta (rounded)
+
+				if (audio.sincInterpolation) // decide which sinc LUT to use according to the resampling ratio
+				{
+					if (delta <= sincDownsample1Ratio)
 						v->fSincLUT = fKaiserSinc;
-					else if (delta <= (uintCPUWord_t)(1.5 * MIXER_FRAC_SCALE))
+					else if (delta <= sincDownsample2Ratio)
 						v->fSincLUT = fDownSample1;
 					else
 						v->fSincLUT = fDownSample2;
-
-					// set scope delta
-					const double dHz2ScopeDeltaMul = SCOPE_FRAC_SCALE / (double)SCOPE_HZ;
-					v->scopeDelta = (intCPUWord_t)((dHz * dHz2ScopeDeltaMul) + 0.5); // Hz -> fixed-point delta (rounded)
 				}
+
+				// set scope delta
+				const double dHz2ScopeDeltaMul = SCOPE_FRAC_SCALE / (double)SCOPE_HZ;
+				v->scopeDelta = (int64_t)((dHz * dHz2ScopeDeltaMul) + 0.5); // Hz -> fixed-point delta (rounded)
 			}
 
 			v->delta = v->oldDelta;
@@ -418,18 +418,21 @@ void updateVoices(void)
 	}
 }
 
-static void sendSamples16BitStereo(uint8_t *stream, uint32_t sampleBlockLength)
+static void sendSamples16BitStereo(void *stream, uint32_t sampleBlockLength)
 {
-	int16_t *streamPointer16 = (int16_t *)stream;
+	int16_t *streamPtr16 = (int16_t *)stream;
 	for (uint32_t i = 0; i < sampleBlockLength; i++)
 	{
-		int32_t L = (int32_t)((double)audio.fMixBufferL[i] * dAudioNormalizeMul);
-		CLAMP16(L);
-		*streamPointer16++ = (int16_t)L;
+		// TODO: This could use dithering (a proper implementation, that is...)
 
-		int32_t R = (int32_t)((double)audio.fMixBufferR[i] * dAudioNormalizeMul);
+		int32_t L = (int32_t)(audio.fMixBufferL[i] * fAudioNormalizeMul);
+		int32_t R = (int32_t)(audio.fMixBufferR[i] * fAudioNormalizeMul);
+
+		CLAMP16(L);
 		CLAMP16(R);
-		*streamPointer16++ = (int16_t)R;
+
+		*streamPtr16++ = (int16_t)L;
+		*streamPtr16++ = (int16_t)R;
 
 		// clear what we read from the mixing buffer
 		audio.fMixBufferL[i] = 0.0f;
@@ -437,18 +440,16 @@ static void sendSamples16BitStereo(uint8_t *stream, uint32_t sampleBlockLength)
 	}
 }
 
-static void sendSamples32BitFloatStereo(uint8_t *stream, uint32_t sampleBlockLength)
+static void sendSamples32BitFloatStereo(void *stream, uint32_t sampleBlockLength)
 {
-	float *fStreamPointer32 = (float *)stream;
+	float *fStreamPtr32 = (float *)stream;
 	for (uint32_t i = 0; i < sampleBlockLength; i++)
 	{
-		double dL = (double)audio.fMixBufferL[i] * dAudioNormalizeMul;
-		dL = CLAMP(dL, -1.0, 1.0);
-		*fStreamPointer32++ = (float)dL;
+		const float fL = audio.fMixBufferL[i] * fAudioNormalizeMul;
+		const float fR = audio.fMixBufferR[i] * fAudioNormalizeMul;
 
-		double dR = (double)audio.fMixBufferR[i] * dAudioNormalizeMul;
-		dR = CLAMP(dR, -1.0, 1.0);
-		*fStreamPointer32++ = (float)dR;
+		*fStreamPtr32++ = CLAMP(fL, -1.0f, 1.0f);
+		*fStreamPtr32++ = CLAMP(fR, -1.0f, 1.0f);
 
 		// clear what we read from the mixing buffer
 		audio.fMixBufferL[i] = 0.0f;
@@ -465,37 +466,20 @@ static void doChannelMixing(int32_t bufferPosition, int32_t samplesToMix)
 	{
 		if (v->active)
 		{
-			bool centerMixFlag;
-
 			const bool volRampFlag = (v->volumeRampLength > 0);
-			if (volRampFlag)
-			{
-				centerMixFlag = (v->fTargetVolumeL == v->fTargetVolumeR) && (v->fVolumeLDelta == v->fVolumeRDelta);
-			}
-			else // no volume ramping active
-			{
-				if (v->fCurrVolumeL == 0.0f && v->fCurrVolumeR == 0.0f)
-				{
-					silenceMixRoutine(v, samplesToMix);
-					continue;
-				}
-
-				centerMixFlag = (v->fCurrVolumeL == v->fCurrVolumeR);
-			}
-
-			mixFuncTab[((int32_t)centerMixFlag * (3*4*2*2)) + ((int32_t)volRampFlag * (3*4*2)) + v->mixFuncOffset](v, bufferPosition, samplesToMix);
+			if (!volRampFlag && v->fCurrVolumeL == 0.0f && v->fCurrVolumeR == 0.0f)
+				silenceMixRoutine(v, samplesToMix);
+			else
+				mixFuncTab[((int32_t)volRampFlag * (3*5*2)) + v->mixFuncOffset](v, bufferPosition, samplesToMix);
 		}
 
 		if (r->active) // volume ramp fadeout-voice
-		{
-			const bool centerMixFlag = (r->fTargetVolumeL == r->fTargetVolumeR) && (r->fVolumeLDelta == r->fVolumeRDelta);
-			mixFuncTab[((int32_t)centerMixFlag * (3*4*2*2)) + (3*4*2) + r->mixFuncOffset](r, bufferPosition, samplesToMix);
-		}
+			mixFuncTab[(3*5*2) + r->mixFuncOffset](r, bufferPosition, samplesToMix);
 	}
 }
 
 // used for song-to-WAV renderer
-void mixReplayerTickToBuffer(uint32_t samplesToMix, uint8_t *stream, uint8_t bitDepth)
+void mixReplayerTickToBuffer(uint32_t samplesToMix, void *stream, uint8_t bitDepth)
 {
 	doChannelMixing(0, samplesToMix);
 
@@ -1000,11 +984,7 @@ bool setupAudio(bool showErrorMsg)
 		return false;
 	}
 
-#if CPU_64BIT
 	if (have.freq != 44100 && have.freq != 48000 && have.freq != 96000)
-#else // 32-bit CPUs only support .16fp resampling precision. Not sensible with high rates.
-	if (have.freq != 44100 && have.freq != 48000)
-#endif
 	{
 		if (showErrorMsg)
 			showErrorMsgBox("Couldn't open audio device:\nThis program doesn't support an audio output rate of %dHz. Sorry!", have.freq);
