@@ -139,15 +139,15 @@ bool setupGUI(void)
 
 	// set uninitialized GUI struct entries
 
-	textBox_t *t = &textBoxes[1]; // skip first entry, it's reserved for inputBox())
+	textBox_t *t = &textBoxes[1]; // skip first entry, it's reserved for inputBox()
 	for (int32_t i = 1; i < NUM_TEXTBOXES; i++, t++)
 	{
 		t->visible = false;
 		t->bufOffset = 0;
 		t->cursorPos = 0;
 		t->textPtr = NULL;
-		t->renderBufW = (9 + 1) * t->maxChars; // 9 = max character/glyph width possible
-		t->renderBufH = 10; // 10 = max character height possible
+		t->renderBufW = (9 + 1) * t->maxChars; // 9 = max text glyph width (+1 for kerning)
+		t->renderBufH = 10; // 10 = max text glyph height
 		t->renderW = t->w - (t->tx * 2);
 
 		t->renderBuf = (uint8_t *)malloc(t->renderBufW * t->renderBufH * sizeof (int8_t));
@@ -370,52 +370,6 @@ void charOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 	}
 }
 
-void charOutAlpha(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr, uint32_t alpha)
-{
-	assert(xPos < SCREEN_W && yPos < SCREEN_H);
-
-	chr &= 0x7F; // this is important to get the nordic glyphs in the font
-	if (chr == ' ')
-		return;
-
-	if (alpha > 65536)
-		alpha = 65536;
-
-	const uint32_t pixVal = video.palette[paletteIndex];
-	const uint32_t palNum = paletteIndex << 24;
-	const uint8_t *srcPtr = &bmp.font1[chr * FONT1_CHAR_W];
-	uint32_t *dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
-
-	for (int32_t y = 0; y < FONT1_CHAR_H; y++)
-	{
-		for (int32_t x = 0; x < FONT1_CHAR_W; x++)
-		{
-			const uint32_t srcPixel = srcPtr[x];
-			if (srcPixel == 0)
-				continue;
-
-			const uint32_t dstPixel = dstPtr[x];
-
-			const int32_t srcR = RGB32_R(pixVal);
-			const int32_t srcG = RGB32_G(pixVal);
-			const int32_t srcB = RGB32_B(pixVal);
-
-			int32_t dstR = RGB32_R(dstPixel);
-			int32_t dstG = RGB32_G(dstPixel);
-			int32_t dstB = RGB32_B(dstPixel);
-
-			dstR = ((dstR * (65536-alpha)) + (srcR * alpha)) >> 16;
-			dstG = ((dstG * (65536-alpha)) + (srcG * alpha)) >> 16;
-			dstB = ((dstB * (65536-alpha)) + (srcB * alpha)) >> 16;
-
-			dstPtr[x] = RGB32(dstR, dstG, dstB) | palNum;
-		}
-
-		srcPtr += FONT1_WIDTH;
-		dstPtr += SCREEN_W;
-	}
-}
-
 void charOutBg(uint16_t xPos, uint16_t yPos, uint8_t fgPalette, uint8_t bgPalette, char chr)
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
@@ -585,31 +539,6 @@ void textOut(uint16_t x, uint16_t y, uint8_t paletteIndex, const char *textPtr)
 	}
 }
 
-void textOutAlpha(uint16_t x, uint16_t y, uint8_t paletteIndex, const char *textPtr, uint32_t alpha)
-{
-	char chr;
-	uint16_t currX;
-
-	assert(textPtr != NULL);
-
-	if (alpha >= 65536)
-	{
-		textOut(x, y, paletteIndex, textPtr);
-		return;
-	}
-
-	currX = x;
-	while (true)
-	{
-		chr = *textPtr++;
-		if (chr == '\0')
-			break;
-
-		charOutAlpha(currX, y, paletteIndex, chr, alpha);
-		currX += charWidth(chr);
-	}
-}
-
 void textOutBorder(uint16_t x, uint16_t y, uint8_t paletteIndex, uint8_t borderPaletteIndex, const char *textPtr)
 {
 	textOut(x,   y-1, borderPaletteIndex, textPtr); // top
@@ -812,47 +741,6 @@ void blit32(uint16_t xPos, uint16_t yPos, const uint32_t *srcPtr, uint16_t w, ui
 	}
 }
 
-void blit32Alpha(uint16_t xPos, uint16_t yPos, const uint32_t *srcPtr, uint16_t w, uint16_t h, uint32_t alpha)
-{
-	assert(srcPtr != NULL && xPos < SCREEN_W && yPos < SCREEN_H && (xPos + w) <= SCREEN_W && (yPos + h) <= SCREEN_H);
-
-	if (alpha >= 65536)
-	{
-		blit32(xPos, yPos, srcPtr, w, h);
-		return;
-	}
-
-	uint32_t *dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
-	for (int32_t y = 0; y < h; y++)
-	{
-		for (int32_t x = 0; x < w; x++)
-		{
-			const uint32_t srcPixel = srcPtr[x];
-			if (srcPixel == 0x00FF00)
-				continue;
-
-			const uint32_t dstPixel = dstPtr[x];
-
-			const int32_t srcR = RGB32_R(srcPixel);
-			const int32_t srcG = RGB32_G(srcPixel);
-			const int32_t srcB = RGB32_B(srcPixel);
-
-			int32_t dstR = RGB32_R(dstPixel);
-			int32_t dstG = RGB32_G(dstPixel);
-			int32_t dstB = RGB32_B(dstPixel);
-
-			dstR = ((dstR * (65536-alpha)) + (srcR * alpha)) >> 16;
-			dstG = ((dstG * (65536-alpha)) + (srcG * alpha)) >> 16;
-			dstB = ((dstB * (65536-alpha)) + (srcB * alpha)) >> 16;
-
-			dstPtr[x] = RGB32(dstR, dstG, dstB) | 0xFF000000; // most significant 8 bits = palette number. 0xFF because no true palette
-		}
-
-		srcPtr += w;
-		dstPtr += SCREEN_W;
-	}
-}
-
 void blit(uint16_t xPos, uint16_t yPos, const uint8_t *srcPtr, uint16_t w, uint16_t h)
 {
 	assert(srcPtr != NULL && xPos < SCREEN_W && yPos < SCREEN_H && (xPos + w) <= SCREEN_W && (yPos + h) <= SCREEN_H);
@@ -1359,7 +1247,7 @@ void showTopScreen(bool restoreScreens)
 
 void showBottomScreen(void)
 {
-	if (ui.extended || ui.patternEditorShown)
+	if (ui.extendedPatternEditor || ui.patternEditorShown)
 		showPatternEditor();
 	else if (ui.instEditorShown)
 		showInstEditor();
