@@ -35,10 +35,6 @@
 #include "ft2_structs.h"
 #include "ft2_hpc.h"
 
-#ifdef HAS_MIDI
-static SDL_Thread *initMidiThread;
-#endif
-
 static void initializeVars(void);
 static void cleanUpAndExit(void); // never call this inside the main loop
 #ifdef __APPLE__
@@ -135,6 +131,7 @@ int main(int argc, char *argv[])
 		showErrorMsgBox("Couldn't initialize SDL:\n%s", SDL_GetError());
 		return 1;
 	}
+
 	SDL_EventState(SDL_DROPFILE, SDL_ENABLE);
 
 	/* Text input is started by default in SDL2, turn it off to remove ~2ms spikes per key press.
@@ -149,19 +146,14 @@ int main(int argc, char *argv[])
 #ifdef __APPLE__
 	osxSetDirToProgramDirFromArgs(argv);
 #endif
-	if (!setupExecutablePath() || !loadBMPs())
+	if (!setupExecutablePath() || !loadBMPs() || !calcCubicSplineTable() || !calcWindowedSincTables())
 	{
 		cleanUpAndExit();
 		return 1;
 	}
 
-	if (!calcWindowedSincTables()) // must be called before config is loaded
-	{
-		cleanUpAndExit();
-		return false;
-	}
+	loadConfigOrSetDefaults(); // config must be loaded at this exact point
 
-	loadConfigOrSetDefaults();
 	if (!setupWindow() || !setupRenderer())
 	{
 		// error message was shown in the functions above
@@ -213,6 +205,7 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
+	initAboutScreen();
 	pauseAudio();
 	resumeAudio();
 	rescanAudioDevices();
@@ -228,15 +221,18 @@ int main(int argc, char *argv[])
 	}
 
 #ifdef HAS_MIDI
-	// set up MIDI input (in a thread because it can take quite a while on f.ex. macOS)
-	initMidiThread = SDL_CreateThread(initMidiFunc, NULL, NULL);
-	if (initMidiThread == NULL)
+#ifdef __APPLE__
+	// MIDI init can take several seconds on Mac, use thread
+	midi.initMidiThread = SDL_CreateThread(initMidiFunc, NULL, NULL);
+	if (midi.initMidiThread == NULL)
 	{
 		showErrorMsgBox("Couldn't create MIDI initialization thread!");
 		cleanUpAndExit();
 		return 1;
 	}
-	SDL_DetachThread(initMidiThread); // don't wait for this thread, let it clean up when done
+#else
+	initMidiFunc(NULL);
+#endif
 #endif
 
 	hpc_ResetCounters(&video.vblankHpc); // quirk: this is needed for potential okBox() calls in handleModuleLoadFromArg()
@@ -269,6 +265,9 @@ static void initializeVars(void)
 	cpu.hasSSE2 = SDL_HasSSE2();
 
 	// clear common structs
+#ifdef HAS_MIDI
+	memset(&midi, 0, sizeof (midi));
+#endif
 	memset(&video, 0, sizeof (video));
 	memset(&keyb, 0, sizeof (keyb));
 	memset(&mouse, 0, sizeof (mouse));
@@ -287,7 +286,7 @@ static void initializeVars(void)
 
 	// now set data that must be initialized to non-zero values...
 
-	audio.locked = true;
+	audio.locked = true; // XXX: Why..?
 	audio.rescanAudioDevicesSupported = true;
 
 	// set non-zero values
@@ -303,7 +302,7 @@ static void initializeVars(void)
 	editor.srcInstr = 1;
 	editor.curInstr = 1;
 	editor.curOctave = 4;
-	editor.smpEd_NoteNr = 48 + 1; // middle-C
+	editor.smpEd_NoteNr = 1+NOTE_C4;
 
 	editor.ptnJumpPos[0] = 0x00;
 	editor.ptnJumpPos[1] = 0x10;
@@ -314,25 +313,46 @@ static void initializeVars(void)
 	memset(editor.copyMask, 1, sizeof (editor.copyMask));
 	memset(editor.pasteMask, 1, sizeof (editor.pasteMask));
 
-#ifdef HAS_MIDI
-	midi.enable = true;
-#endif
-
 	editor.diskOpReadOnOpen = true;
 
 	audio.linearPeriodsFlag = true;
 	calcReplayerLogTab();
 
+#ifdef HAS_MIDI
+	midi.enable = true;
+#endif
+
 	editor.programRunning = true;
 }
 
 static void cleanUpAndExit(void) // never call this inside the main loop!
 {
 #ifdef HAS_MIDI
-	if (midi.closeMidiOnExit)
+#ifdef __APPLE__
+	// on Mac we used a thread to init MIDI (as it could take several seconds)
+	if (midi.initMidiThread != NULL)
 	{
-		closeMidiInDevice();
-		freeMidiIn();
+		SDL_WaitThread(midi.initMidiThread, NULL);
+		midi.initMidiThread = NULL;
+	}
+#endif
+	midi.enable = false; // stop MIDI callback from doing things
+	while (midi.callbackBusy) SDL_Delay(1); // wait for MIDI callback to finish
+
+	closeMidiInDevice();
+	freeMidiIn();
+	freeMidiInputDeviceList();
+
+	if (midi.inputDeviceName != NULL)
+	{
+		free(midi.inputDeviceName);
+		midi.inputDeviceName = NULL;
+	}
+
+	if (editor.midiConfigFileLocationU != NULL)
+	{
+		free(editor.midiConfigFileLocationU);
+		editor.midiConfigFileLocationU = NULL;
 	}
 #endif
 
@@ -343,22 +363,11 @@ static void cleanUpAndExit(void) // never call this inside the main loop!
 	freeDiskOp();
 	clearCopyBuffer();
 	freeAudioDeviceSelectorBuffers();
-#ifdef HAS_MIDI
-	freeMidiInputDeviceList();
-#endif
 	windUpFTHelp();
 	freeTextBoxes();
 	freeMouseCursors();
 	freeBMPs();
 
-#ifdef HAS_MIDI
-	if (midi.inputDeviceName != NULL)
-	{
-		free(midi.inputDeviceName);
-		midi.inputDeviceName = NULL;
-	}
-#endif
-
 	if (editor.audioDevConfigFileLocationU != NULL)
 	{
 		free(editor.audioDevConfigFileLocationU);
@@ -371,12 +380,6 @@ static void cleanUpAndExit(void) // never call this inside the main loop!
 		editor.configFileLocationU = NULL;
 	}
 
-	if (editor.midiConfigFileLocationU != NULL)
-	{
-		free(editor.midiConfigFileLocationU);
-		editor.midiConfigFileLocationU = NULL;
-	}
-
 	if (editor.binaryPathU != NULL)
 	{
 		free(editor.binaryPathU);
@@ -394,7 +397,7 @@ static void cleanUpAndExit(void) // never call this inside the main loop!
 static void osxSetDirToProgramDirFromArgs(char **argv)
 {
 	/* OS X/macOS: hackish way of setting the current working directory to the place where we double clicked
-	** on the icon (for protracker.ini loading)
+	** on the icon (for FT2.CFG loading)
 	*/
 
 	// if we launched from the terminal, argv[0][0] would be '.'
