@@ -33,6 +33,10 @@ extern mouse_t mouse; // ft2_mouse.c
 #define MOUSE_GLASS_ANI_FRAMES 22
 #define MOUSE_CLOCK_ANI_FRAMES 5
 
+#if defined __APPLE__ && defined __aarch64__
+void armMacGhostMouseCursorFix(void);
+#endif
+
 void freeMouseCursors(void);
 bool createMouseCursors(void);
 void setMousePosToCenter(void);
