@@ -104,7 +104,7 @@ static void drawWindow(uint16_t w)
 {
 	const uint16_t h = SYSTEM_REQUEST_H;
 	const uint16_t x = (SCREEN_W - w) / 2;
-	const uint16_t y = ui.extended ? 91 : SYSTEM_REQUEST_Y;
+	const uint16_t y = ui.extendedPatternEditor ? 91 : SYSTEM_REQUEST_Y;
 
 	// main fill
 	fillRect(x + 1, y + 1, w - 2, h - 2, PAL_BUTTONS);
@@ -164,6 +164,10 @@ static bool mouseButtonDownLogic(uint8_t mouseButton)
 
 static bool mouseButtonUpLogic(uint8_t mouseButton)
 {
+#if defined __APPLE__ && defined __aarch64__
+	armMacGhostMouseCursorFix();
+#endif
+
 	if (mouseButton == SDL_BUTTON_LEFT)
 		mouse.leftButtonPressed = false;
 	else if (mouseButton == SDL_BUTTON_RIGHT)
@@ -229,7 +233,7 @@ int16_t okBox(int16_t type, const char *headline, const char *text, void (*check
 	const uint16_t x = (SCREEN_W - wlen) / 2;
 
 	// the dialog's y position differs in extended pattern editor mode
-	const uint16_t y = ui.extended ? SYSTEM_REQUEST_Y_EXT : SYSTEM_REQUEST_Y;
+	const uint16_t y = ui.extendedPatternEditor ? SYSTEM_REQUEST_Y_EXT : SYSTEM_REQUEST_Y;
 
 	// set up buttons
 	for (uint16_t i = 0; i < numButtons; i++)
@@ -334,7 +338,12 @@ int16_t okBox(int16_t type, const char *headline, const char *text, void (*check
 					if (testCheckBoxMouseDown()) continue;
 				}
 			}
-
+#if defined __APPLE__ && defined __aarch64__
+			else if (inputEvent.type == SDL_MOUSEMOTION)
+			{
+				armMacGhostMouseCursorFix();
+			}
+#endif
 			if (!ui.sysReqShown)
 				break;
 		}
@@ -447,7 +456,7 @@ int16_t inputBox(int16_t type, const char *headline, char *edText, uint16_t maxS
 		wlen = 600;
 
 	// the box y position differs in extended pattern editor mode
-	const uint16_t y = ui.extended ? SYSTEM_REQUEST_Y_EXT : SYSTEM_REQUEST_Y;
+	const uint16_t y = ui.extendedPatternEditor ? SYSTEM_REQUEST_Y_EXT : SYSTEM_REQUEST_Y;
 
 	// set further text box settings
 	t->x = (SCREEN_W - TEXTBOX_W) / 2;
@@ -572,7 +581,12 @@ int16_t inputBox(int16_t type, const char *headline, char *edText, uint16_t maxS
 					if (testPushButtonMouseDown()) continue;
 				}
 			}
-
+#if defined __APPLE__ && defined __aarch64__
+			else if (inputEvent.type == SDL_MOUSEMOTION)
+			{
+				armMacGhostMouseCursorFix();
+			}
+#endif
 			if (!ui.sysReqShown)
 				break;
 		}
