@@ -17,7 +17,7 @@ const uint16_t ptPeriods[3 * 12] =
 	214,202,190,180,170,160,151,143,135,127,120,113
 };
 
-const uint8_t arpTab[256] =
+const uint8_t arpeggioTab[256] =
 {
 	0,1,2,0,1,2,0,1,2,0,1,2,0,1,2,0,
 	
@@ -61,13 +61,13 @@ const int8_t autoVibSineTab[256] =
 	 24,  23,  22,  20,  19,  17,  16,  14,  12,  11,   9,   8,   6,   5,   3,   2
 };
 
-const uint8_t vibTab[32] = // for normal vibrato/tremolo
+const uint8_t vibratoTab[32] = // for normal vibrato/tremolo
 {
 	  0, 24, 49, 74, 97,120,141,161,180,197,212,224,235,244,250,253,
 	255,253,250,244,235,224,212,197,180,161,141,120, 97, 74, 49, 24
 };
 
-const uint16_t amigaPeriod[8 * 12] = // used for .MOD loading/saving
+const uint16_t modPeriods[8 * 12] = // used for .MOD loading/saving
 {
 	6848, 6464, 6096, 5760, 5424, 5120, 4832, 4560, 4304, 4064, 3840, 3624,
 	3424, 3232, 3048, 2880, 2712, 2560, 2416, 2280, 2152, 2032, 1920, 1812,
@@ -325,9 +325,10 @@ const uint16_t amigaPeriods[1936] = // bit-exact to FT2 table
 	   36,    35,    35,    35,    35,    35,    35,    35,    35,    34,    34,    34,    34,    34,    34,    34,
 	   34,    33,    33,    33,    33,    33,    33,    33,    33,    32,    32,    32,    32,    32,    32,    32,
 	   32,    32,    32,    31,    31,    31,    31,    31,    31,    31,    31,    30,    30,    30,    30,    30,
-	   30,    30,    30,    30,    30,    29,    29,    29,    29,    29,    29,    29,    29,    29,    29,    22,
-	   16,     8,     0,    16,    32,    24,    16,     8,     0,    16,    32,    24,    16,     8,     0,     0
-	   // the last 17 values are off (but identical to FT2) because of a bug in how FT2 calculates this table
+	   30,    30,    30,    30,    30,    29,    29,    29,    29,    29,    29,    29,    29,    29,    29,
+
+	   // these last values are wrong (but identical to FT2) because of a bug in how FT2 calculates this table
+	   22, 16, 8, 0, 16, 32, 24, 16, 8, 0, 16, 32, 24, 16, 8, 0, 0
 };
 
 /* ----------------------------------------------------------------------- */
@@ -470,11 +471,12 @@ const int8_t maxVisibleChans2[4] = { 4, 6, 8, 12 };
 
 const uint16_t chanWidths[6] = { 141, 141, 93, 69, 45, 45 };
 
+// for pattern marking
 const pattCoordsMouse_t pattCoordMouseTable[2][2][2] =
 {
 	/*
-		uint16_t upperRowsY, midRowY, lowerRowsY;
-		uint16_t numUpperRows;
+	struct organization:
+	   upperRowsY, midRowY, lowerRowsY, numUpperRows
 	*/
 
 	// no pattern stretch
@@ -482,13 +484,13 @@ const pattCoordsMouse_t pattCoordMouseTable[2][2][2] =
 		// no pattern channel scroll
 		{
 			{ 177, 281, 293, 13 }, //   normal pattern editor
-			{  57, 217, 229, 20 }, // extended pattern editor
+			{  73, 225, 237, 19 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 177, 274, 286, 12 }, //   normal pattern editor
-			{  57, 210, 222, 19 }, // extended pattern editor
+			{  73, 225, 237, 19 }, // extended pattern editor
 		}
 	},
 
@@ -497,13 +499,13 @@ const pattCoordsMouse_t pattCoordMouseTable[2][2][2] =
 		// no pattern channel scroll
 		{
 			{ 176, 275, 286,  9 }, //   normal pattern editor
-			{  56, 221, 232, 15 }, // extended pattern editor
+			{  75, 229, 240, 14 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
-			{ 175, 274, 284,  9 }, //   normal pattern editor
-			{  55, 209, 219, 14 }, // extended pattern editor
+			{ 175, 274, 283,  9 }, //   normal pattern editor
+			{  73, 277, 238, 14 }, // extended pattern editor
 		},
 	}
 };
@@ -564,20 +566,26 @@ const uint8_t hex2Dec[256] =
 	80,81,82,83,84,85
 };
 
+// for actual pattern data drawing
 const pattCoord_t pattCoordTable[2][2][2] =
 {
+	/*
+	struct organization:
+	   upperRowsY, lowerRowsY, upperRowsTextY, midRowTextY, lowerRowsTextY, numUpperRows, numLowerRows
+	*/
+
 	// no pattern stretch
 	{
 		// no pattern channel scroll
 		{
 			{ 176, 292, 177, 283, 293, 13, 13 }, // normal pattern editor
-			{  56, 228,  57, 219, 229, 20, 21 }, // extended pattern editor
+			{  71, 236,  73, 227, 237, 19, 20 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 176, 285, 177, 276, 286, 12, 12 }, // normal pattern editor
-			{  56, 221,  57, 212, 222, 19, 20 }, // extended pattern editor
+			{  71, 236,  73, 227, 237, 19, 18 }, // extended pattern editor
 		}
 	},
 
@@ -586,31 +594,37 @@ const pattCoord_t pattCoordTable[2][2][2] =
 		// no pattern channel scroll
 		{
 			{ 177, 286, 178, 277, 288,  9, 10 }, // normal pattern editor
-			{  56, 232,  58, 223, 234, 15, 15 }, // extended pattern editor
+			{  71, 240,  77, 231, 242, 14, 14 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{  176, 285, 177, 276, 286,  9,  9 }, // normal pattern editor
-			{   56, 220,  57, 211, 221, 14, 15 }, // extended pattern editor
+			{   71, 238,  75, 229, 240, 14, 13 }, // extended pattern editor
 		},
 	}
 };
 
+// for framework drawing
 const pattCoord2_t pattCoord2Table[2][2][2] =
 {
+	/*
+	struct organization:
+	   upperRowsY, lowerRowsY, upperRowsH, lowerRowsH
+	*/
+
 	// no pattern stretch
 	{
 		// no pattern channel scroll
 		{
 			{ 175, 291, 107, 107 }, //   normal pattern editor
-			{  55, 227, 163, 171 }, // extended pattern editor
+			{  70, 235, 156, 163 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 175, 284, 100, 100 }, //   normal pattern editor
-			{  55, 220, 156, 164 }, // extended pattern editor
+			{  70, 235, 156, 149 }, // extended pattern editor
 		}
 	},
 
@@ -619,31 +633,36 @@ const pattCoord2_t pattCoord2Table[2][2][2] =
 		// no pattern channel scroll
 		{
 			{ 175, 285, 101, 113 }, //   normal pattern editor
-			{  55, 231, 167, 167 }, // extended pattern editor
+			{  70, 239, 160, 159 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 175, 284, 100, 100 }, //   normal pattern editor
-			{  55, 219, 155, 165 }, // extended pattern editor
+			{  70, 237, 158, 148 }, // extended pattern editor
 		},
 	}
 };
 
 const markCoord_t markCoordTable[2][2][2] =
 {
+	/*
+	struct organization:
+	   upperRowsY, midRowY, lowerRowsY
+	*/
+
 	// no pattern stretch
 	{
 		// no pattern channel scroll
 		{
 			{ 177, 281, 293 }, //   normal pattern editor
-			{  57, 217, 229 }, // extended pattern editor
+			{  73, 225, 237 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 177, 274, 286 }, //   normal pattern editor
-			{  57, 210, 222 }, // extended pattern editor
+			{  73, 225, 237 }, // extended pattern editor
 		}
 	},
 
@@ -652,13 +671,13 @@ const markCoord_t markCoordTable[2][2][2] =
 		// no pattern channel scroll
 		{
 			{ 176, 275, 286 }, //   normal pattern editor
-			{  56, 221, 232 }, // extended pattern editor
+			{  75, 229, 240 }, // extended pattern editor
 		},
 
 		// pattern channel scroll
 		{
 			{ 175, 274, 284 }, //   normal pattern editor
-			{  55, 209, 219 }, // extended pattern editor
+			{  73, 227, 238 }, // extended pattern editor
 		},
 	}
 };
